REGIONS = {u'ad': u'\u0b06\u0b28\u0b21\u0b4b\u0b30\u0b3e',
 u'ae': u'U.A.E.',
 u'af': u'\u0b06\u0b2b\u0b17\u0b3e\u0b28\u0b3f\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'ag': u'\u0b0f\u0b23\u0b4d\u0b1f\u0b3f\u0b17\u0b41\u0b06 \u0b0f\u0b2c\u0b02 \u0b2c\u0b3e\u0b30\u0b4d\u0b2c\u0b41\u0b21\u0b3e',
 u'ai': u'\u0b06\u0b19\u0b4d\u0b17\u0b41\u0b07\u0b32\u0b3e',
 u'al': u'\u0b06\u0b32\u0b2c\u0b3e\u0b28\u0b3f\u0b06',
 u'am': u'\u0b06\u0b30\u0b2e\u0b47\u0b28\u0b3f\u0b06',
 u'an': u'\u0b28\u0b47\u0b26\u0b30\u0b32\u0b4d\u0b2f\u0b3e\u0b23\u0b4d\u0b21 \u0b0f\u0b23\u0b4d\u0b1f\u0b3e\u0b07\u0b32\u0b38',
 u'ao': u'\u0b0f\u0b19\u0b4d\u0b17\u0b4b\u0b32\u0b3e',
 u'aq': u'\u0b06\u0b23\u0b4d\u0b1f\u0b3e\u0b30\u0b4d\u0b15\u0b1f\u0b3f\u0b15\u0b3e',
 u'ar': u'\u0b06\u0b30\u0b4d\u0b1c\u0b47\u0b23\u0b4d\u0b1f\u0b3f\u0b28\u0b3e',
 u'as': u'\u0b06\u0b2e\u0b47\u0b30\u0b3f\u0b15\u0b3e\u0b28 \u0b38\u0b3e\u0b2e\u0b06',
 u'at': u'\u0b05\u0b37\u0b4d\u0b1f\u0b4d\u0b30\u0b3f\u0b06',
 u'au': u'\u0b05\u0b37\u0b4d\u0b1f\u0b4d\u0b30\u0b47\u0b32\u0b3f\u0b06',
 u'aw': u'\u0b06\u0b30\u0b41\u0b2c\u0b3e',
 u'ax': u'\xc5land \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'az': u'\u0b06\u0b1c\u0b3e\u0b30\u0b2c\u0b3e\u0b07\u0b1c\u0b3e\u0b28',
 u'ba': u'\u0b2c\u0b4b\u0b38\u0b28\u0b3f\u0b06 \u0b0f\u0b2c\u0b02 \u0b39\u0b3e\u0b30\u0b4d\u0b1c\u0b47\u0b17\u0b4b\u0b2d\u0b3f\u0b28\u0b3e',
 u'bb': u'\u0b2c\u0b3e\u0b30\u0b4d\u0b2c\u0b3e\u0b21\u0b4b\u0b38',
 u'bd': u'\u0b2c\u0b3e\u0b19\u0b4d\u0b17\u0b32\u0b3e\u0b26\u0b47\u0b36',
 u'be': u'\u0b2c\u0b47\u0b32\u0b1c\u0b3f\u0b5f\u0b2e',
 u'bf': u'\u0b2c\u0b41\u0b30\u0b4d\u0b15\u0b3f\u0b28\u0b3e \u0b2b\u0b3e\u0b38\u0b4b',
 u'bg': u'\u0b2c\u0b41\u0b32\u0b17\u0b47\u0b30\u0b3f\u0b06',
 u'bh': u'\u0b2c\u0b3e\u0b39\u0b3e\u0b30\u0b3e\u0b28',
 u'bi': u'\u0b2c\u0b41\u0b30\u0b41\u0b23\u0b4d\u0b21\u0b3f',
 u'bj': u'\u0b2c\u0b47\u0b28\u0b3f\u0b28',
 u'bl': u'Saint Barth\xe9lemy',
 u'bm': u'\u0b2c\u0b30\u0b2e\u0b41\u0b21\u0b3c\u0b3e',
 u'bn': u'\u0b2c\u0b4d\u0b30\u0b41\u0b28\u0b47\u0b07 \u0b1c\u0b47\u0b30\u0b41\u0b1c\u0b47\u0b32\u0b2e',
 u'bo': u'\u0b2c\u0b32\u0b3f\u0b2d\u0b3f\u0b06',
 u'br': u'\u0b2c\u0b4d\u0b30\u0b3e\u0b1c\u0b3f\u0b32',
 u'bs': u'\u0b2c\u0b3e\u0b39\u0b3e\u0b2e\u0b3e\u0b38',
 u'bt': u'\u0b2d\u0b41\u0b1f\u0b3e\u0b28',
 u'bv': u'\u0b2c\u0b09\u0b2d\u0b47\u0b1f \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'bw': u'\u0b2c\u0b1f\u0b38\u0b71\u0b3e\u0b28\u0b3e',
 u'by': u'\u0b2c\u0b47\u0b32\u0b3e\u0b30\u0b38',
 u'bz': u'\u0b2c\u0b47\u0b32\u0b3f\u0b1c',
 u'ca': u'\u0b15\u0b3e\u0b28\u0b3e\u0b21\u0b3e',
 u'cc': u'\u0b15\u0b4b\u0b15\u0b4b\u0b38 (\u0b15\u0b3f\u0b32\u0b3f\u0b19\u0b4d\u0b17) \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'cd': u'\u0b15\u0b4b\u0b19\u0b4d\u0b17\u0b4b-\u0b15\u0b3f\u0b28\u0b36\u0b3e\u0b38\u0b3e',
 u'cf': u'\u0b2e\u0b27\u0b4d\u0b2f \u0b06\u0b2b\u0b4d\u0b30\u0b3f\u0b15\u0b3f\u0b5f \u0b17\u0b23\u0b24\u0b28\u0b4d\u0b24\u0b4d\u0b30',
 u'cg': u'\u0b15\u0b4b\u0b19\u0b4d\u0b17\u0b4b-\u0b2c\u0b4d\u0b30\u0b3e\u0b1c\u0b47\u0b2d\u0b3e\u0b07\u0b32',
 u'ch': u'\u0b38\u0b4d\u0b71\u0b3f\u0b1c\u0b30\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'ci': u'\u0b06\u0b07\u0b2d\u0b30\u0b3f \u0b15\u0b4b\u0b37\u0b4d\u0b1a',
 u'ck': u'\u0b15\u0b41\u0b15 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'cl': u'\u0b1a\u0b3f\u0b32\u0b3f',
 u'cm': u'\u0b15\u0b3e\u0b2e\u0b47\u0b30\u0b41\u0b28',
 u'cn': u'\u0b1a\u0b3f\u0b28',
 u'co': u'\u0b15\u0b4b\u0b32\u0b2e\u0b2c\u0b3f\u0b06',
 u'cr': u'\u0b15\u0b4b\u0b37\u0b4d\u0b1f\u0b3e \u0b30\u0b3f\u0b15\u0b3e',
 u'cu': u'\u0b15\u0b4d\u0b5f\u0b41\u0b2c\u0b3e',
 u'cv': u'\u0b15\u0b4d\u0b5f\u0b47\u0b2a \u0b2c\u0b30\u0b4d\u0b26\u0b47',
 u'cx': u'\u0b15\u0b4d\u0b30\u0b3f\u0b37\u0b4d\u0b1f\u0b2e\u0b3e\u0b38 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'cy': u'\u0b38\u0b3e\u0b07\u0b2a\u0b4d\u0b30\u0b3e\u0b38',
 u'cz': u'\u0b15\u0b47\u0b1a \u0b17\u0b23\u0b24\u0b28\u0b4d\u0b24\u0b4d\u0b30',
 u'de': u'\u0b1c\u0b30\u0b4d\u0b2e\u0b3e\u0b28',
 u'dj': u'\u0b1c\u0b3f\u0b2c\u0b09\u0b1f\u0b3f',
 u'dk': u'\u0b21\u0b47\u0b28\u0b2e\u0b3e\u0b30\u0b4d\u0b15',
 u'dm': u'\u0b21\u0b2e\u0b3f\u0b28\u0b3f\u0b15\u0b3e',
 u'do': u'\u0b21\u0b2e\u0b3f\u0b28\u0b3f\u0b15\u0b3e \u0b17\u0b23\u0b24\u0b28\u0b4d\u0b24\u0b4d\u0b30',
 u'dz': u'\u0b06\u0b32\u0b1c\u0b47\u0b30\u0b3f\u0b06',
 u'ec': u'\u0b07\u0b15\u0b4d\u0b5f\u0b41\u0b0f\u0b21\u0b30',
 u'ee': u'\u0b0f\u0b38\u0b1f\u0b4b\u0b28\u0b3f\u0b06',
 u'eg': u'\u0b07\u0b1c\u0b3f\u0b2a\u0b4d\u0b1f',
 u'eh': u'\u0b2a\u0b36\u0b4d\u0b1a\u0b3f\u0b2e\u0b3f \u0b38\u0b3e\u0b39\u0b3e\u0b30\u0b3e',
 u'er': u'\u0b07\u0b30\u0b3f\u0b1f\u0b4d\u0b30\u0b3f',
 u'es': u'\u0b38\u0b4d\u0b2a\u0b47\u0b28',
 u'et': u'\u0b07\u0b25\u0b3f\u0b13\u0b2a\u0b3f\u0b06',
 u'fi': u'\u0b2b\u0b3f\u0b28\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'fj': u'\u0b2b\u0b3f\u0b1c\u0b3f',
 u'fk': u'\u0b2b\u0b15\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21 (\u0b2e\u0b3e\u0b32\u0b3e\u0b26\u0b4d\u0b71\u0b40\u0b2a)',
 u'fm': u'\u0b2e\u0b3e\u0b07\u0b15\u0b4d\u0b30\u0b4b\u0b28\u0b47\u0b38\u0b3f\u0b06',
 u'fo': u'\u0b2b\u0b47\u0b30\u0b0f \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'fr': u'\u0b2b\u0b4d\u0b30\u0b3e\u0b28\u0b38',
 u'ga': u'\u0b17\u0b3e\u0b2c\u0b28',
 u'gb': u'\u0b2f\u0b41\u0b15\u0b4d\u0b24 \u0b30\u0b3e\u0b1c\u0b4d\u0b5f',
 u'gd': u'\u0b17\u0b4d\u0b30\u0b47\u0b28\u0b3e\u0b21\u0b3e',
 u'ge': u'\u0b1c\u0b30\u0b4d\u0b1c\u0b3f\u0b06',
 u'gf': u'\u0b2b\u0b4d\u0b30\u0b47\u0b1e\u0b4d\u0b1a \u0b17\u0b41\u0b06\u0b28\u0b3e',
 u'gg': u'\u0b17\u0b41\u0b0f\u0b30\u0b4d\u0b28\u0b1c\u0b47',
 u'gh': u'\u0b18\u0b3e\u0b28\u0b3e',
 u'gi': u'\u0b17\u0b3f\u0b2c\u0b4d\u0b30\u0b3e\u0b32\u0b1f\u0b30',
 u'gl': u'\u0b17\u0b4d\u0b30\u0b3f\u0b28\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'gm': u'\u0b17\u0b3e\u0b2e\u0b2c\u0b3f\u0b06',
 u'gn': u'\u0b17\u0b3f\u0b28\u0b3f',
 u'gp': u'\u0b17\u0b41\u0b06\u0b21\u0b47\u0b32\u0b2a',
 u'gq': u'\u0b07\u0b15\u0b4d\u0b5f\u0b41\u0b0f\u0b1f\u0b30\u0b3f\u0b06\u0b32 \u0b17\u0b3f\u0b28\u0b3f',
 u'gr': u'\u0b17\u0b4d\u0b30\u0b3f\u0b38',
 u'gs': u'South Georgia and the South Sandwich Islands',
 u'gt': u'\u0b17\u0b41\u0b06\u0b1f\u0b47\u0b2e\u0b3e\u0b32\u0b3e',
 u'gu': u'\u0b17\u0b41\u0b06\u0b2e',
 u'gw': u'\u0b17\u0b3f\u0b28\u0b3f-\u0b2c\u0b3f\u0b38\u0b3e\u0b13',
 u'gy': u'\u0b17\u0b41\u0b06\u0b28\u0b3e',
 u'hk': u'\u0b39\u0b19\u0b4d\u0b17 \u0b15\u0b19\u0b4d\u0b17',
 u'hm': u'\u0b39\u0b3e\u0b30\u0b4d\u0b21 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21 \u0b0f\u0b2c\u0b02 \u0b2e\u0b4d\u0b5f\u0b3e\u0b15 \u0b21\u0b28\u0b3e\u0b32\u0b4d\u0b21 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'hn': u'\u0b39\u0b23\u0b4d\u0b21\u0b41\u0b30\u0b38',
 u'hr': u'\u0b15\u0b4d\u0b30\u0b4b\u0b0f\u0b38\u0b3f\u0b06',
 u'ht': u'\u0b39\u0b3e\u0b07\u0b24\u0b3f',
 u'hu': u'\u0b39\u0b3e\u0b19\u0b4d\u0b17\u0b3e\u0b30\u0b3f',
 u'id': u'\u0b07\u0b23\u0b4d\u0b21\u0b4b\u0b28\u0b47\u0b38\u0b3f\u0b06',
 u'ie': u'\u0b06\u0b07\u0b30\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'il': u'\u0b07\u0b1c\u0b4d\u0b30\u0b3e\u0b0f\u0b32',
 u'im': u'\u0b07\u0b38\u0b32\u0b47 \u0b05\u0b2b \u0b2e\u0b4d\u0b5f\u0b3e\u0b28',
 u'in': u'\u0b2d\u0b3e\u0b30\u0b24',
 u'io': u'\u0b2c\u0b4d\u0b30\u0b3f\u0b1f\u0b3f\u0b36 \u0b2d\u0b3e\u0b30\u0b24 \u0b2e\u0b39\u0b3e\u0b38\u0b3e\u0b17\u0b30 \u0b2a\u0b4d\u0b30\u0b26\u0b47\u0b36',
 u'iq': u'\u0b07\u0b30\u0b3e\u0b15',
 u'ir': u'\u0b07\u0b30\u0b3e\u0b28',
 u'is': u'\u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'it': u'\u0b07\u0b1f\u0b3e\u0b32\u0b3f',
 u'je': u'\u0b1c\u0b47\u0b30\u0b38\u0b3f',
 u'jm': u'\u0b1c\u0b3e\u0b2e\u0b3e\u0b07\u0b15\u0b3e',
 u'jo': u'\u0b1c\u0b4b\u0b30\u0b4d\u0b21\u0b3e\u0b28',
 u'jp': u'\u0b1c\u0b3e\u0b2a\u0b3e\u0b28',
 u'ke': u'\u0b15\u0b47\u0b28\u0b3f\u0b5f\u0b3e',
 u'kg': u'\u0b15\u0b3f\u0b30\u0b17\u0b3f\u0b1c\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'kh': u'\u0b15\u0b3e\u0b2e\u0b4d\u0b2c\u0b4b\u0b21\u0b3f\u0b06',
 u'ki': u'\u0b15\u0b3f\u0b30\u0b3f\u0b2c\u0b3e\u0b1f\u0b3f',
 u'km': u'\u0b15\u0b2e\u0b30\u0b38',
 u'kn': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b15\u0b3f\u0b1f\u0b38 \u0b0f\u0b2c\u0b02 \u0b28\u0b47\u0b2d\u0b3f\u0b38',
 u'kp': u'\u0b09\u0b24\u0b4d\u0b24\u0b30 \u0b15\u0b4b\u0b30\u0b3f\u0b06',
 u'kr': u'\u0b26\u0b15\u0b4d\u0b37\u0b3f\u0b23 \u0b15\u0b4b\u0b30\u0b3f\u0b06',
 u'kw': u'\u0b15\u0b41\u0b0f\u0b24',
 u'ky': u'\u0b15\u0b47\u0b2e\u0b4d\u0b5f\u0b3e\u0b28 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'kz': u'\u0b15\u0b3e\u0b1c\u0b3e\u0b15\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'la': u'\u0b32\u0b3e\u0b13\u0b38',
 u'lb': u'\u0b32\u0b47\u0b2c\u0b47\u0b28\u0b28',
 u'lc': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b32\u0b41\u0b38\u0b3f\u0b06',
 u'li': u'\u0b32\u0b3f\u0b1a\u0b47\u0b28\u0b38\u0b4d\u0b1f\u0b47\u0b28',
 u'lk': u'\u0b38\u0b4d\u0b30\u0b3f\u0b32\u0b19\u0b4d\u0b15\u0b3e',
 u'lr': u'\u0b32\u0b3f\u0b2c\u0b47\u0b30\u0b3f\u0b06',
 u'ls': u'\u0b32\u0b47\u0b38\u0b4b\u0b25\u0b4b',
 u'lt': u'\u0b32\u0b3f\u0b25\u0b41\u0b06\u0b28\u0b3f\u0b06',
 u'lu': u'\u0b32\u0b17\u0b1c\u0b47\u0b2e\u0b2c\u0b30\u0b4d\u0b17',
 u'lv': u'\u0b32\u0b3e\u0b1f\u0b2d\u0b3f\u0b06',
 u'ly': u'\u0b32\u0b3f\u0b2c\u0b4d\u0b5f\u0b3e',
 u'ma': u'\u0b2e\u0b4b\u0b30\u0b4b\u0b15\u0b4d\u0b15\u0b4b',
 u'mc': u'\u0b2e\u0b4b\u0b28\u0b3e\u0b15\u0b4b',
 u'md': u'\u0b2e\u0b4b\u0b32\u0b21\u0b4b\u0b2d\u0b3e',
 u'me': u'\u0b2e\u0b23\u0b4d\u0b1f\u0b47\u0b28\u0b47\u0b17\u0b4d\u0b30\u0b4b',
 u'mf': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b2e\u0b3e\u0b30\u0b4d\u0b1f\u0b3f\u0b28',
 u'mg': u'\u0b2e\u0b3e\u0b21\u0b3e\u0b17\u0b3e\u0b38\u0b15\u0b3e\u0b30',
 u'mh': u'\u0b2e\u0b3e\u0b30\u0b4d\u0b36\u0b3e\u0b32 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'mk': u'\u0b2e\u0b47\u0b38\u0b3f\u0b21\u0b4b\u0b28\u0b3f\u0b06, F.Y.R. of',
 u'ml': u'\u0b2e\u0b3e\u0b32\u0b3f',
 u'mm': u'\u0b2e\u0b4d\u0b5f\u0b3e\u0b28\u0b2e\u0b3e\u0b30',
 u'mn': u'\u0b2e\u0b4b\u0b19\u0b4d\u0b17\u0b4b\u0b32\u0b3f\u0b06',
 u'mo': u'\u0b2e\u0b3e\u0b15\u0b3e\u0b13',
 u'mp': u'\u0b09\u0b24\u0b4d\u0b24\u0b30 \u0b2e\u0b47\u0b30\u0b3f\u0b06\u0b28\u0b3e \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'mq': u'\u0b2e\u0b3e\u0b30\u0b4d\u0b1f\u0b3f\u0b28\u0b3f\u0b15',
 u'mr': u'\u0b2e\u0b4b\u0b30\u0b3f\u0b1f\u0b3e\u0b28\u0b3f\u0b06',
 u'ms': u'\u0b2e\u0b28\u0b1f\u0b38\u0b47\u0b30\u0b47\u0b1f',
 u'mt': u'\u0b2e\u0b3e\u0b32\u0b1f\u0b3e',
 u'mu': u'\u0b2e\u0b4b\u0b30\u0b3f\u0b38\u0b3f\u0b05\u0b38',
 u'mv': u'\u0b2e\u0b3e\u0b32\u0b3e\u0b26\u0b4d\u0b71\u0b40\u0b2a',
 u'mw': u'\u0b2e\u0b3e\u0b32\u0b3e\u0b71\u0b3f',
 u'mx': u'\u0b2e\u0b47\u0b15\u0b38\u0b3f\u0b15',
 u'my': u'\u0b2e\u0b3e\u0b32\u0b5f\u0b47\u0b38\u0b3f\u0b06',
 u'mz': u'\u0b2e\u0b4b\u0b1c\u0b3e\u0b2e\u0b2c\u0b3f\u0b15',
 u'na': u'\u0b28\u0b3e\u0b2e\u0b3f\u0b2c\u0b3f\u0b06',
 u'nc': u'\u0b28\u0b3f\u0b5f\u0b41 \u0b15\u0b3e\u0b32\u0b47\u0b21\u0b4b\u0b28\u0b3f\u0b06',
 u'ne': u'\u0b28\u0b3e\u0b07\u0b1c\u0b47\u0b30',
 u'nf': u'\u0b28\u0b30\u0b2b\u0b15 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'ng': u'\u0b28\u0b3e\u0b07\u0b1c\u0b47\u0b30\u0b3f\u0b06',
 u'ni': u'\u0b28\u0b3f\u0b15\u0b3e\u0b30\u0b3e\u0b17\u0b41',
 u'nl': u'\u0b28\u0b47\u0b26\u0b30\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'no': u'\u0b28\u0b30\u0b71\u0b47',
 u'np': u'\u0b28\u0b47\u0b2a\u0b3e\u0b33',
 u'nr': u'\u0b28\u0b3e\u0b09\u0b30\u0b41',
 u'nu': u'\u0b28\u0b3f\u0b5f\u0b41',
 u'nz': u'\u0b28\u0b4d\u0b5f\u0b41\u0b1c\u0b3f\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'om': u'\u0b13\u0b2e\u0b3e\u0b28',
 u'pa': u'\u0b2a\u0b3e\u0b28\u0b3e\u0b2e\u0b3e',
 u'pe': u'\u0b2a\u0b47\u0b30\u0b41',
 u'pf': u'\u0b2b\u0b4d\u0b30\u0b3e\u0b28\u0b38 \u0b2a\u0b32\u0b3f\u0b28\u0b47\u0b38\u0b3f\u0b06',
 u'pg': u'\u0b2a\u0b2a\u0b41\u0b06 \u0b28\u0b3f\u0b5f\u0b41 \u0b17\u0b3f\u0b28\u0b3f',
 u'ph': u'\u0b2b\u0b3f\u0b32\u0b3f\u0b2a\u0b3f\u0b28\u0b38',
 u'pk': u'\u0b2a\u0b3e\u0b15\u0b3f\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'pl': u'\u0b2a\u0b4b\u0b32\u0b3e\u0b23\u0b4d\u0b21',
 u'pm': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b2a\u0b3f\u0b0f\u0b30 \u0b0f\u0b2c\u0b02 \u0b2e\u0b3f\u0b15\u0b4d\u0b71\u0b47\u0b32\u0b28',
 u'pn': u'\u0b2a\u0b3f\u0b1f\u0b15\u0b48\u0b30\u0b4d\u0b23\u0b4d\u0b23',
 u'pr': u'\u0b2a\u0b41\u0b0f\u0b30\u0b4d\u0b24\u0b4d\u0b24 \u0b30\u0b3f\u0b15\u0b4b',
 u'ps': u'\u0b05\u0b27\u0b3f\u0b15\u0b43\u0b24 \u0b2a\u0b3e\u0b32\u0b47\u0b38\u0b4d\u0b1f\u0b3f\u0b28\u0b3f\u0b06\u0b28 \u0b2a\u0b4d\u0b30\u0b26\u0b47\u0b36',
 u'pt': u'\u0b2a\u0b30\u0b4d\u0b24\u0b4d\u0b24\u0b41\u0b17\u0b3e\u0b32',
 u'pw': u'\u0b2a\u0b3e\u0b32\u0b3e\u0b09',
 u'py': u'\u0b2a\u0b3e\u0b30\u0b3e\u0b17\u0b41\u0b0f',
 u'qa': u'\u0b15\u0b24\u0b3e\u0b30',
 u're': u'\u0b30\u0b3f\u0b5f\u0b41\u0b28\u0b3f\u0b05\u0b28',
 u'ro': u'\u0b30\u0b4b\u0b2e\u0b3e\u0b28\u0b3f\u0b06',
 u'rs': u'\u0b38\u0b30\u0b4d\u0b2c\u0b3f\u0b06',
 u'ru': u'\u0b30\u0b41\u0b38\u0b3f\u0b06\u0b28 \u0b2b\u0b47\u0b21\u0b47\u0b30\u0b47\u0b38\u0b28',
 u'rw': u'\u0b71\u0b3e\u0b23\u0b4d\u0b21\u0b3e',
 u'sa': u'\u0b38\u0b3e\u0b09\u0b26\u0b3f \u0b06\u0b30\u0b2c\u0b3f',
 u'sb': u'\u0b38\u0b4b\u0b32\u0b4b\u0b2e\u0b28 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'sc': u'\u0b38\u0b3f\u0b1a\u0b47\u0b32\u0b38',
 u'sd': u'\u0b38\u0b41\u0b26\u0b3e\u0b28',
 u'se': u'\u0b38\u0b4d\u0b71\u0b3f\u0b21\u0b47\u0b28',
 u'sg': u'\u0b38\u0b3f\u0b19\u0b4d\u0b17\u0b3e\u0b2a\u0b4b\u0b30',
 u'sh': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b39\u0b47\u0b32\u0b47\u0b28\u0b3e',
 u'si': u'\u0b38\u0b4d\u0b32\u0b4b\u0b2d\u0b47\u0b28\u0b3f\u0b06',
 u'sj': u'\u0b2d\u0b3e\u0b32\u0b2c\u0b3e\u0b30\u0b4d\u0b21 \u0b0f\u0b2c\u0b02 \u0b1c\u0b3e\u0b28 \u0b2e\u0b3e\u0b5f\u0b47\u0b28',
 u'sk': u'\u0b38\u0b4d\u0b32\u0b4b\u0b2d\u0b3e\u0b15\u0b3f\u0b06',
 u'sl': u'\u0b38\u0b3f\u0b0f\u0b30\u0b3e \u0b32\u0b3f\u0b13\u0b28',
 u'sm': u'\u0b38\u0b3e\u0b28 \u0b2e\u0b47\u0b30\u0b3f\u0b28\u0b4b',
 u'sn': u'\u0b38\u0b47\u0b28\u0b47\u0b17\u0b3e\u0b32',
 u'so': u'\u0b38\u0b4b\u0b2e\u0b3e\u0b32\u0b3f\u0b06',
 u'sr': u'\u0b38\u0b41\u0b30\u0b3f\u0b28\u0b47\u0b2e',
 u'st': u'\u0b38\u0b3e\u0b13 \u0b1f\u0b2e \u0b0f\u0b2c\u0b02 \u0b2a\u0b4d\u0b30\u0b3f\u0b28\u0b38\u0b3f\u0b2a',
 u'sv': u'\u0b0f\u0b32 \u0b38\u0b3e\u0b32\u0b2d\u0b3e\u0b21\u0b30',
 u'sy': u'\u0b38\u0b3f\u0b30\u0b3f\u0b06',
 u'sz': u'\u0b38\u0b4d\u0b71\u0b3e\u0b1c\u0b3f\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'tc': u'\u0b24\u0b41\u0b30\u0b4d\u0b15 \u0b0f\u0b2c\u0b02 \u0b15\u0b3e\u0b07\u0b15\u0b38 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'td': u'\u0b1a\u0b3e\u0b26',
 u'tf': u'\u0b2b\u0b4d\u0b30\u0b3e\u0b28\u0b38 \u0b26\u0b15\u0b4d\u0b37\u0b3f\u0b23 \u0b2a\u0b4d\u0b30\u0b26\u0b47\u0b36',
 u'tg': u'\u0b1f\u0b47\u0b3e\u0b17\u0b4b',
 u'th': u'\u0b25\u0b3e\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'tj': u'\u0b24\u0b3e\u0b1c\u0b3f\u0b15\u0b3f\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'tk': u'\u0b24\u0b15\u0b47\u0b32\u0b09',
 u'tl': u'\u0b24\u0b3f\u0b2e\u0b4b\u0b30-\u0b32\u0b47\u0b38\u0b4d\u0b24\u0b47',
 u'tm': u'\u0b24\u0b41\u0b30\u0b4d\u0b15\u0b2e\u0b47\u0b28\u0b3f\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'tn': u'\u0b24\u0b41\u0b28\u0b3f\u0b38\u0b3f\u0b06',
 u'to': u'\u0b24\u0b19\u0b4d\u0b17\u0b3e',
 u'tr': u'\u0b24\u0b41\u0b30\u0b4d\u0b15\u0b40',
 u'tt': u'\u0b24\u0b4d\u0b30\u0b3f\u0b28\u0b3f\u0b26\u0b3e\u0b26\u0b0f\u0b2c\u0b02 \u0b24\u0b2c\u0b3e\u0b17\u0b4b',
 u'tv': u'\u0b24\u0b41\u0b71\u0b3e\u0b32\u0b41',
 u'tw': u'\u0b24\u0b3e\u0b07\u0b71\u0b3e\u0b28',
 u'tz': u'\u0b1f\u0b3e\u0b1e\u0b4d\u0b1c\u0b3e\u0b28\u0b3f\u0b06',
 u'ua': u'\u0b5f\u0b41\u0b15\u0b4d\u0b30\u0b47\u0b28',
 u'ug': u'\u0b09\u0b17\u0b3e\u0b23\u0b4d\u0b21\u0b3e',
 u'um': u'\u0b2f\u0b41\u0b15\u0b4d\u0b24\u0b30\u0b3e\u0b37\u0b4d\u0b1f\u0b4d\u0b30 \u0b2e\u0b3e\u0b07\u0b28\u0b30 \u0b06\u0b09\u0b1f\u0b32\u0b3e\u0b07\u0b19\u0b4d\u0b17 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'us': u'\u0b2f\u0b41\u0b15\u0b4d\u0b24\u0b30\u0b3e\u0b37\u0b4d\u0b1f\u0b4d\u0b30',
 u'uy': u'\u0b09\u0b30\u0b41\u0b17\u0b41\u0b5f\u0b47',
 u'uz': u'\u0b09\u0b1c\u0b2c\u0b47\u0b15\u0b3f\u0b38\u0b4d\u0b25\u0b3e\u0b28',
 u'va': u'\u0b2d\u0b3e\u0b1f\u0b3f\u0b15\u0b3e\u0b28 \u0b38\u0b3f\u0b1f\u0b3f',
 u'vc': u'\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b2d\u0b3f\u0b28\u0b38\u0b47\u0b23\u0b4d\u0b1f \u0b0f\u0b2c\u0b02 \u0b17\u0b4d\u0b30\u0b47\u0b28\u0b47\u0b21\u0b3e\u0b07\u0b28',
 u've': u'\u0b2d\u0b47\u0b28\u0b3f\u0b1c\u0b41\u0b0f\u0b32\u0b3e',
 u'vg': u'\u0b2c\u0b4d\u0b30\u0b3f\u0b1f\u0b3f\u0b36 \u0b2d\u0b3f\u0b30\u0b1c\u0b3f\u0b28 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'vi': u'U.S. \u0b2d\u0b3f\u0b30\u0b1c\u0b3f\u0b28 \u0b06\u0b07\u0b32\u0b4d\u0b5f\u0b3e\u0b23\u0b4d\u0b21',
 u'vn': u'\u0b2d\u0b3f\u0b0f\u0b24\u0b28\u0b3e\u0b2e',
 u'vu': u'\u0b2d\u0b3e\u0b28\u0b41\u0b06\u0b24\u0b41',
 u'wf': u'\u0b71\u0b3e\u0b32\u0b3f\u0b38 \u0b0f\u0b2c\u0b02 \u0b2b\u0b4d\u0b5f\u0b41\u0b1a\u0b41\u0b28\u0b3e',
 u'ws': u'\u0b38\u0b3e\u0b2e\u0b4b\u0b06',
 u'ye': u'\u0b5f\u0b47\u0b2e\u0b47\u0b28',
 u'yt': u'\u0b2e\u0b3e\u0b5f\u0b4b\u0b1f',
 u'za': u'\u0b26\u0b15\u0b4d\u0b37\u0b3f\u0b23 \u0b06\u0b2b\u0b4d\u0b30\u0b3f\u0b15\u0b3e',
 u'zm': u'\u0b1c\u0b3e\u0b2e\u0b4d\u0b2c\u0b3f\u0b06',
 u'zw': u'\u0b1c\u0b3f\u0b2e\u0b4d\u0b2c\u0b3e\u0b71\u0b47'}